@@ -2,12 +2,13 @@
 from collective.anysurfer.interfaces import ILayerSpecific as IAnysurferLayer
 from cpskin.locales import CPSkinMessageFactory as _
 from plone.app.contenttypes.interfaces import IPloneAppContenttypesLayer
+from plone.app.event.interfaces import IBrowserLayer
 from sc.social.like.interfaces import ISocialLikeLayer
 from zope import schema
 from zope.interface import Interface
 
 
-class ICPSkinCoreLayer(ISocialLikeLayer, IPloneAppContenttypesLayer, IAnysurferLayer):
+class ICPSkinCoreLayer(ISocialLikeLayer, IPloneAppContenttypesLayer, IAnysurferLayer, IBrowserLayer):
     """
     Marker interface that defines a ZTK browser layer.
     """
